package net.idylls.tickle

import org.slf4j.LoggerFactory

import com.google.inject.Provides
import javax.inject.Inject

import net.runelite.api.Client
import net.runelite.client.plugins.Plugin
import net.runelite.client.plugins.PluginDescriptor
import net.runelite.client.config.ConfigManager
import net.runelite.client.ui.overlay.OverlayManager
import net.runelite.client.ui.ClientToolbar
import net.runelite.client.ui.NavigationButton
import net.runelite.client.eventbus.Subscribe
import net.runelite.api.events.GameTick;
import net.runelite.client.util.ImageUtil

@PluginDescriptor(
	name = "Tickle"
)
public class TicklePlugin : Plugin() {
	val log = LoggerFactory.getLogger(TicklePlugin::class.java)

	@Inject
	lateinit var clientToolbar: ClientToolbar

	@Inject
	lateinit var client: Client

	@Inject
	lateinit final var overlayManager: OverlayManager

	@Inject
	lateinit var panel: Panel

	@Inject
	lateinit var overlay: Overlay

	lateinit var navButton: NavigationButton;

	var ticksSinceLogin: Int = 0
	var lastTickTime = System.nanoTime()

	lateinit var worldsStats: WorldsStats

	override fun startUp() {
		log.info("Tickle started")

		val icon = ImageUtil.loadImageResource(this::class.java, "icon_temp.png");

		this.navButton = NavigationButton.builder()
			.tooltip("Tickle")
			.icon(icon)
			.priority(8)
			.panel(panel)
			.build()

		this.clientToolbar.addNavigation(this.navButton)
		this.overlayManager.add(this.overlay)
		this.worldsStats = WorldsStats(this.client)
	}

	override fun shutDown() {
		this.clientToolbar.removeNavigation(this.navButton)
		this.overlayManager.remove(this.overlay)
	}

	@Subscribe
	fun onGameTick(tick: GameTick) {
		val now = System.nanoTime()

		this.ticksSinceLogin++

		if (ticksSinceLogin > 30) {
			val diff = ((now - this.lastTickTime) / 1000000).toInt()

			this.worldsStats.current()?.track(diff)
			this.panel.updateCurrentPanel()
		}

		this.lastTickTime = now
	}
}
